=======
Feature
=======

Features in Abaqus/CAE include Parts, Datums, Partitions, and Assembly operations. The commands that create Feature objects on only the Part object are described in Part commands. The commands that create Feature objects in only the rootAssembly object are described in Assembly commands. The commands that create Feature objects on both the Part and the rootAssembly objects are described here.


Classes
-------

Feature
~~~~~~~

.. autoclass:: abaqus.Feature.Feature.Feature
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

FeatureOptions
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Feature.FeatureOptions.FeatureOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
